function [phi] = transform(psi,t,pars,vecs)
% Apply the projectors to psi and conduct the transformation phi^+ =
% e^(it/ep^2) psi^+, phi^- = e^(-it/ep^2) psi^-

% Input: psi is a two-component function discretizized on x_(-M),...,x_(M-1)
% --> psi is a vector of length 4*M
%       psi(    1:2*M,:) --> psi_1 at nodes x_(-M),...,x_(M-1)
%       psi(2*M+1:4*M,:) --> psi_2 at nodes x_(-M),...,x_(M-1)

% Output: phi is two two-component functions phi^+ and phi^-.
% --> phi is a vector of length 8*M
%       phi(    1:2*M,:) --> phi^+_1 at nodes x_(-M),...,x_(M-1)
%       psi(2*M+1:4*M,:) --> psi^+_2 at nodes x_(-M),...,x_(M-1)
%       phi(4*M+1:6*M,:) --> phi^-_1 at nodes x_(-M),...,x_(M-1)
%       psi(6*M+1:8*M,:) --> psi^-_2 at nodes x_(-M),...,x_(M-1)

M = size(psi,1)/4;

% Projectors require Fourier space representation of psi
psi = fft_C2(psi);

phi = zeros(8*M,1);
% phi^+
phi(    1:4*M) = exp( 1i*t/pars.ep^2) * plus_projector_C2(  psi ,pars,vecs.proj );
%phi^-
phi(4*M+1:8*M) = exp(-1i*t/pars.ep^2) * minus_projector_C2( psi ,pars,vecs.proj );

% Retransform phi from Fourier space
phi = ifft_2C2(phi);

end

