function [psi] = fft_2C2(psi)
% Calculate the Fourier transform for two two-component functions saved in
% psi
% --> psi is a vector of length 8*M
%       psi(    1:2*M,:) --> phi^+_1 at nodes x_(-M),...,x_(M-1)
%       psi(2*M+1:4*M,:) --> psi^+_2 at nodes x_(-M),...,x_(M-1)
%       psi(4*M+1:6*M,:) --> phi^-_1 at nodes x_(-M),...,x_(M-1)
%       psi(6*M+1:8*M,:) --> psi^-_2 at nodes x_(-M),...,x_(M-1)

% --> Apply fft_C2 to the first and second half of the vector psi seperately

% mat is a logical variable
% mat = 0 --> psi is a vector containing only one column
% mat = 1 --> psi is a matrix with several columns, apply fft to each of
% them
sz = size(psi);

M = sz(1)/8;

if sz(2) == 1 % psi is a vector
    psi = [ fft_C2( psi(1:4*M) ) ; fft_C2( psi(4*M+1:8*M) ) ];
else % psi is a matrix
    psi = [ fft_C2( psi(1:4*M,:) ) ; fft_C2( psi(4*M+1:8*M,:) )];
end

end

