function [psi] = fft_C2(psi)
% Calculate the Fourier transform for a two component function psi

% psi is a vector of length 4*M:
% psi(1:2*M)     --> Evaluations of psi_1 at knots x_(-M),...,x_(M-1)
% psi(2*M+1:4*M) --> Evaluations of psi_2 at knots x_(-M),...,x_(M-1)

% --> Apply fft to the first and second half of the vector psi seperately

% mat is a logical variable
% mat = 0 --> psi is a vector containing only one column
% mat = 1 --> psi is a matrix with several columns, apply fft to each of
% them

sz = size(psi);

M = sz(1)/4;

if sz(2) == 1 % psi is a vector
    psi = [ myfft( psi(1:2*M) ) ; myfft( psi(2*M+1:4*M) )];
else % psi is a matrix
    psi = [ myfft( psi(1:2*M,:) ) ; myfft( psi(2*M+1:4*M,:) )];
end

end

