
% Input:  The function values of a 2pi-periodic function f:[-pi,pi] ---> IC
%         u(j) = f(x_j),   x_j=j*2pi/L
%         j=-kmax,...,kmax-1   if L=2*kmax   is even
%         j=-kmax,...,kmax     if L=2*kmax+1 is odd
%         Falls L gerade: Funktionswerte an den Stellen
%           -pi, -pi+h, ..., -h, 0 ,h, ... pi-h
%         Falls L ungerade: Funktionswerte symmetrisch um 0 herum, Stellen
%         -pi/pi sind nicht dabei:
%           -(L-1)/2*h, (-(L-1)/2-1)h, ... , -h, 0, h, ..., (L-1)/2*h
%         = -pi+h/2                    ...                   pi-h/2
%
% Output: The Fourier coefficients fhat such that
%         f(x_j) = sum_{k=-kmax}^{kmax-1} fhat(k)*exp(i*k*x_j)
%                  if L is even, L = 2*kmax
%         f(x_j) = sum_{k=-kmax}^{kmax} fhat(k)*exp(i*k*x_j)
%                  if L is odd, L = 2*kmax+1
%         out(j) = fhat(-kmax-1+j),   j=1, ..., L
%
% If the input is a matrix with more than one row (i.e. not a row vector),
% then the operation is done column-wise.
%
% WARNING: A row vector is treated like a column vector, NOT like a matrix.
% This makes a difference!

function v = myfft(u)

s = size(u);
if length(s)>2
    fprintf('\n\n\n')
    fprintf('*** Error in myfft: The input must be a column vector or a matrix. *** \n\n\n')
    keyboard
end
L=s(1);
transp=0;
if L==1
    transp=1;
    u=u.';
    L=s(2);
end
if rem(L-1,2)>0
    % L even
    kmax=round(L/2);
    u=ifftshift(u);
    v=fft(u);
    v=fftshift(v);
    v=v/L;
else
    % L odd
    kmax=round((L-1)/2);
    u=ifftshift(u);
    v=fft(u);
    v=fftshift(v);
    v=v/L;
end

if transp==1
    v=v.';
end



if 0
    % Check result
    clc; clear all hidden;
    kmax=117;
    L=2*kmax+1; kvec=(-kmax:kmax)';
    x=2*pi*kvec/L;
    u=(rand(L,2)-0.5)*[1;1i];
    v=myfft(u);
    uu=zeros(L,1);
    for k=-kmax:kmax
        uu=uu+v(k+kmax+1)*exp(1i*k*x);
    end
    norm(u-uu)
end

end

