function [err_vec] = sobolev_norm(psi,m,M,a,b)
% Berechnet die m-te Sobolev-Norm Spaltenweise, d.h. für jede Spalte von
% psi wird die H^m Norm berechnet

% Beachte: Obere Hälfte von psi --> psi1, Untere Hälfte --> psi2

% Sobolev-Norm: ||v||_{H^m} = sqrt( \sum_{k=-M:M-1} (1+|k|^2)^m |\hat{v}_k|^2  )

% Führe Fourier-Transformation durch, berechne Quadrat des Betrags der
% Fourierkoeffizienten
psi1 = abs(myfft(psi(1:2*M,:))).^2;
psi2 = abs(myfft(psi(2*M+1:4*M,:))).^2;
% Erstelle Multiplikationsvektor (1+|2*pi/(b-a)*k|^2)^m, k=-M:M-1
mutl_vec = transpose( (1+(2*pi/(b-a)*(-M:M-1)).^2).^m );
% Wende Multiplikationsvektor auf jede Spalte an, summiere die Spalten (=
% Summation über alle k)
psi1 = sum( mutl_vec.*psi1 );
psi2 = sum( mutl_vec.*psi2 );
% --> Erhalten: Quadrat der Sobolev-Norm jeder Komponente --> mit Euklid-Norm
% die Komponenten psi1 und psi2 zusammenrechnen
err_vec = sqrt(psi1 + psi2);
end

