function [psi,psi_four] = timestep_EEMR_start(psi,psi_four,t_start,pars,vecs)
% Perform one timestep of the double VoC method

% Storage scheme:
% Psi (and all other vectors corresponding to two component functions) is a
% vector of size 8*M:
% Psi(    1:2*M) --> Psi^+_1 at the nodes x_(-M),...,x_(M-1)
% Psi(2*M+1:4*M) --> Psi^+_2 at the nodes x_(-M),...,x_(M-1)
% Psi(4*M+1:6*M) --> Psi^-_1 at the nodes x_(-M),...,x_(M-1)
% Psi(6*M+1:8*M) --> Psi^-_2 at the nodes x_(-M),...,x_(M-1)
% Thus, to be more precise, 
%   psi = (psi^+,psi^-)^T = (psi^+_1,psi^+_2,psi^-_1,psi^-_2)^T

M = size(psi,1)/8;

%% Apply potential and non-linearity
W_psi = potential_W(psi,pars);
% W_psi_four = fft_2C2(W_psi);
g_0 = abs(psi(    1:2*M)).^2 + abs(psi(2*M+1:4*M)).^2 + ...
      abs(psi(4*M+1:6*M)).^2 + abs(psi(6*M+1:8*M)).^2;
g_0_psi  = repmat(g_0, 4,1) .* psi;
% g_0_psi_four = fft_2C2( g_0_psi );

%% apply projectors
temp = fft_2C2(W_psi + pars.gamma_2 * g_0_psi);
proj_p_W_and_G_psi_four =  plus_projector_2C2(temp,pars,vecs.proj);
proj_m_W_and_G_psi_four = minus_projector_2C2(temp,pars,vecs.proj);

I_four = -1i * [ repmat(vecs.kappa_pl(:,3),2,1) .* proj_p_W_and_G_psi_four(    1:4*M) ; ...
                 repmat(vecs.kappa_mi(:,3),2,1) .* proj_m_W_and_G_psi_four(4*M+1:8*M) ];

%% Calculate psi_new = approximation after one more time step
% Calculate the linear part exp(mp i tau D) psi in Fourier space, add the
% integral I (it is in Fourier space) and perform an inverse Fourier
% transform in the end
psi_four = [repmat(vecs.expD_minus,2,1); ...
            repmat(vecs.expD_plus, 2,1)].* psi_four ...
            + I_four;
psi = ifft_2C2(psi_four);

end

